@@ -988,10 +988,11 @@ class core_calendar_external extends external_api {
      * @param   int     $categoryid The category to be included
      * @param   bool    $includenavigation Whether to include navigation
      * @param   bool    $mini Whether to return the mini month view or not
+     * @param   int     $day The day we want to keep as the current day
      * @return  array
      */
-    public static function get_calendar_monthly_view($year, $month, $courseid, $categoryid, $includenavigation, $mini) {
-        global $DB, $USER, $PAGE;
+    public static function get_calendar_monthly_view($year, $month, $courseid, $categoryid, $includenavigation, $mini, $day) {
+        global $USER, $PAGE;
 
         // Parameter validation.
         $params = self::validate_parameters(self::get_calendar_monthly_view_parameters(), [
@@ -1001,6 +1002,7 @@ class core_calendar_external extends external_api {
             'categoryid' => $categoryid,
             'includenavigation' => $includenavigation,
             'mini' => $mini,
+            'day' => $day,
         ]);
 
         $context = \context_user::instance($USER->id);
@@ -1009,7 +1011,7 @@ class core_calendar_external extends external_api {
 
         $type = \core_calendar\type_factory::get_calendar_instance();
 
-        $time = $type->convert_to_timestamp($params['year'], $params['month'], 1);
+        $time = $type->convert_to_timestamp($params['year'], $params['month'], $params['day']);
         $calendar = \calendar_information::create($time, $params['courseid'], $params['categoryid']);
         self::validate_context($calendar->context);
 
@@ -1045,6 +1047,7 @@ class core_calendar_external extends external_api {
                     false,
                     NULL_ALLOWED
                 ),
+                'day' => new external_value(PARAM_INT, 'Day to be viewed', VALUE_DEFAULT, 1),
             ]
         );
     }
