@@ -27,33 +27,15 @@ defined('MOODLE_INTERNAL') || die();
 
 class tinymce_texteditor extends texteditor {
     /** @var string active version - this is the directory name where to find tinymce code */
-    public $version = '3.5.7b';
+    public $version = '3.5.11';
 
     /**
      * Is the current browser supported by this editor?
      * @return bool
      */
     public function supported_by_browser() {
-        if (check_browser_version('MSIE', 6)) {
-            return true;
-        }
-        if (check_browser_version('Gecko', 20030516)) {
-            return true;
-        }
-        if (check_browser_version('Safari', 412)) {
-            return true;
-        }
-        if (check_browser_version('Chrome', 6)) {
-            return true;
-        }
-        if (check_browser_version('Opera', 9)) {
-            return true;
-        }
-        if (check_browser_version('Safari iOS', 534)) {
-            return true;
-        }
-
-        return false;
+        // We don't support any browsers which it doesn't support.
+        return true;
     }
 
     /**
@@ -95,9 +77,9 @@ class tinymce_texteditor extends texteditor {
      * @param null $fpoptions
      */
     public function use_editor($elementid, array $options=null, $fpoptions=null) {
-        global $PAGE;
-        // Note: use full moodle_url instance to prevent standard JS loader.
-        if (debugging('', DEBUG_DEVELOPER)) {
+        global $PAGE, $CFG;
+        // Note: use full moodle_url instance to prevent standard JS loader, make sure we are using https on profile page if required.
+        if ($CFG->debugdeveloper) {
             $PAGE->requires->js(new moodle_url('/lib/editor/tinymce/tiny_mce/'.$this->version.'/tiny_mce_src.js'));
         } else {
             $PAGE->requires->js(new moodle_url('/lib/editor/tinymce/tiny_mce/'.$this->version.'/tiny_mce.js'));
@@ -110,7 +92,6 @@ class tinymce_texteditor extends texteditor {
 
     protected function get_init_params($elementid, array $options=null) {
         global $CFG, $PAGE, $OUTPUT;
-        require_once($CFG->dirroot . '/lib/editor/tinymce/classes/plugin.php');
 
         //TODO: we need to implement user preferences that affect the editor setup too
 
@@ -127,6 +108,13 @@ class tinymce_texteditor extends texteditor {
             $config->disabledsubplugins = '';
         }
 
+        // Remove the manage files button if requested.
+        if (isset($options['enable_filemanagement']) && !$options['enable_filemanagement']) {
+            if (!strpos($config->disabledsubplugins, 'managefiles')) {
+                $config->disabledsubplugins .= ',managefiles';
+            }
+        }
+
         $fontselectlist = empty($config->fontselectlist) ? '' : $config->fontselectlist;
 
         $langrev = -1;
@@ -139,20 +127,19 @@ class tinymce_texteditor extends texteditor {
             'mode' => "exact",
             'elements' => $elementid,
             'relative_urls' => false,
-            'document_base_url' => $CFG->httpswwwroot,
-            'moodle_plugin_base' => "$CFG->httpswwwroot/lib/editor/tinymce/plugins/",
+            'document_base_url' => $CFG->wwwroot,
+            'moodle_plugin_base' => "$CFG->wwwroot/lib/editor/tinymce/plugins/",
             'content_css' => $contentcss,
             'language' => $lang,
             'directionality' => $directionality,
             'plugin_insertdate_dateFormat ' => $strdate,
             'plugin_insertdate_timeFormat ' => $strtime,
             'theme' => "advanced",
-            'skin' => "o2k7",
-            'skin_variant' => "silver",
+            'skin' => "moodle",
             'apply_source_formatting' => true,
             'remove_script_host' => false,
             'entity_encoding' => "raw",
-            'plugins' => 'safari,table,style,layer,advhr,advlink,emotions,inlinepopups,' .
+            'plugins' => 'lists,table,style,layer,advhr,advlink,emotions,inlinepopups,' .
                 'searchreplace,paste,directionality,fullscreen,nonbreaking,contextmenu,' .
                 'insertdatetime,save,iespell,preview,print,noneditable,visualchars,' .
                 'xhtmlxtras,template,pagebreak',
@@ -172,8 +159,7 @@ class tinymce_texteditor extends texteditor {
         );
 
         // Should we override the default toolbar layout unconditionally?
-        $customtoolbar = self::parse_toolbar_setting($config->customtoolbar);
-        if ($customtoolbar) {
+        if (!empty($config->customtoolbar) and $customtoolbar = self::parse_toolbar_setting($config->customtoolbar)) {
             $i = 1;
             foreach ($customtoolbar as $line) {
                 $params['theme_advanced_buttons'.$i] = $line;
@@ -184,6 +170,16 @@ class tinymce_texteditor extends texteditor {
             $params['theme_advanced_buttons1'] = '';
         }
 
+        if (!empty($config->customconfig)) {
+            $config->customconfig = trim($config->customconfig);
+            $decoded = json_decode($config->customconfig, true);
+            if (is_array($decoded)) {
+                foreach ($decoded as $k=>$v) {
+                    $params[$k] = $v;
+                }
+            }
+        }
+
         if (!empty($options['legacy']) or !empty($options['noclean']) or !empty($options['trusted'])) {
             // now deal somehow with non-standard tags, people scream when we do not make moodle code xtml strict,
             // but they scream even more when we strip all tags that are not strict :-(
@@ -250,7 +246,6 @@ class tinymce_texteditor extends texteditor {
      */
     public function get_plugin($plugin) {
         global $CFG;
-        require_once($CFG->dirroot . '/lib/editor/tinymce/classes/plugin.php');
         return editor_tinymce_plugin::get($plugin);
     }
 
@@ -262,6 +257,7 @@ class tinymce_texteditor extends texteditor {
      */
     public function get_tinymce_base_url() {
         global $CFG;
-        return new moodle_url("$CFG->httpswwwroot/lib/editor/tinymce/tiny_mce/$this->version/");
+        return new moodle_url("/lib/editor/tinymce/tiny_mce/$this->version/");
     }
+
 }
